#include "debug_messages.h"
#include "nrf_soc.h"
#include "nrf_delay.h"
#include "timestamp.h"


#ifdef S110
/**@brief Function for handling the debug output messages.
 *
 * @param[in]   sys_evt   Event ID.
 */
void on_sys_evt_debug_messages(uint32_t sys_evt)
{

    SEGGER_RTT_printf(0, "[%6dms] SYS Event %d: ", TIMESTAMP*1000/32768, sys_evt);
	switch (sys_evt)
	{
	    case NRF_EVT_HFCLKSTARTED:
	    	SEGGER_RTT_printf(0, "NRF_EVT_HFCLKSTARTED\n");
	    	break;
	    case NRF_EVT_POWER_FAILURE_WARNING:
	    	SEGGER_RTT_printf(0, "NRF_EVT_POWER_FAILURE_WARNING\n");
	    	break;
	    case NRF_EVT_FLASH_OPERATION_SUCCESS:
	    	SEGGER_RTT_printf(0, "NRF_EVT_FLASH_OPERATION_SUCCESS\n");
	    	break;
	    case NRF_EVT_FLASH_OPERATION_ERROR:
	    	SEGGER_RTT_printf(0, "NRF_EVT_FLASH_OPERATION_ERROR\n");
	    	break;
	    case NRF_EVT_RADIO_BLOCKED:
	    	SEGGER_RTT_printf(0, "NRF_EVT_RADIO_BLOCKED\n");
	    	break;
	    case NRF_EVT_RADIO_CANCELED:
	    	SEGGER_RTT_printf(0, "NRF_EVT_RADIO_CANCELED\n");
	    	break;
	    case NRF_EVT_RADIO_SIGNAL_CALLBACK_INVALID_RETURN:
	    	SEGGER_RTT_printf(0, "NRF_EVT_RADIO_SIGNAL_CALLBACK_INVALID_RETURN\n");
	    	break;
	    case NRF_EVT_RADIO_SESSION_IDLE:
	    	SEGGER_RTT_printf(0, "NRF_EVT_RADIO_SESSION_IDLE\n");
	    	break;
	    case NRF_EVT_RADIO_SESSION_CLOSED:
	    	SEGGER_RTT_printf(0, "NRF_EVT_RADIO_SESSION_CLOSED\n");
	    	break;
	    case NRF_EVT_NUMBER_OF_EVTS:
	    	SEGGER_RTT_printf(0, "NRF_EVT_NUMBER_OF_EVTS\n");
	    	break;
	    default:
	    	SEGGER_RTT_printf(0, "Unknown ID\n");
	    	break;
	}
}
#endif


#ifdef S110
/**@brief Function for handling the debug output messages.
 *
 * @param[in]   p_ble_evt   Bluetooth stack event.
 */
void on_ble_evt_debug_messages(ble_evt_t * p_ble_evt)
{
    const ble_gap_evt_t* p_gap_evt = &p_ble_evt->evt.gap_evt;

    SEGGER_RTT_printf(0, "[%6dms] ", TIMESTAMP*1000/32768);

    switch (p_ble_evt->header.evt_id)
    {
        case BLE_GAP_EVT_CONNECTED:
            SEGGER_RTT_printf(0, "BLE GAP Event: Connected to %02x:%02x:%02x:%02x:%02x:%02x\n",  p_gap_evt->params.connected.peer_addr.addr[5], p_gap_evt->params.connected.peer_addr.addr[4], p_gap_evt->params.connected.peer_addr.addr[3], p_gap_evt->params.connected.peer_addr.addr[2], p_gap_evt->params.connected.peer_addr.addr[1], p_gap_evt->params.connected.peer_addr.addr[0]);
            break;
        case BLE_GAP_EVT_DISCONNECTED:
        	SEGGER_RTT_printf(0, "BLE GAP Event: Disconnected (reason = 0x%02x)\n",  p_gap_evt->params.disconnected.reason);
            break;
        case BLE_GAP_EVT_SEC_PARAMS_REQUEST:
        	SEGGER_RTT_printf(0, "BLE GAP Event: BLE_GAP_EVT_SEC_PARAMS_REQUEST\n");
            break;
        case BLE_GATTS_EVT_SYS_ATTR_MISSING:
        	SEGGER_RTT_printf(0, "BLE GAP Event: BLE_GATTS_EVT_SYS_ATTR_MISSING\n");
            break;
        case BLE_GAP_EVT_AUTH_STATUS:
        	SEGGER_RTT_printf(0, "BLE GAP Event: BLE_GAP_EVT_AUTH_STATUS\n");
            break;
        case BLE_GAP_EVT_SEC_INFO_REQUEST:
        	SEGGER_RTT_printf(0, "BLE GAP Event: BLE_GAP_EVT_SEC_INFO_REQUEST\n");
            break;
        case BLE_GAP_EVT_TIMEOUT:
        	SEGGER_RTT_printf(0, "BLE GAP Event: BLE_GAP_EVT_TIMEOUT\n");
            break;
        case BLE_GAP_EVT_CONN_PARAM_UPDATE:
        	SEGGER_RTT_printf(0, "BLE GAP Event: Connection parameters have been updated:\n");
        	SEGGER_RTT_printf(0, "                                   [max. interval]           %d\n", p_gap_evt->params.conn_param_update.conn_params.max_conn_interval);
        	SEGGER_RTT_printf(0, "                                   [min. interval]           %d\n", p_gap_evt->params.conn_param_update.conn_params.min_conn_interval);
        	SEGGER_RTT_printf(0, "                                   [supervision timeout]     %d\n", p_gap_evt->params.conn_param_update.conn_params.conn_sup_timeout);
        	SEGGER_RTT_printf(0, "                                   [slave latency]           %d\n", p_gap_evt->params.conn_param_update.conn_params.slave_latency);
        	break;
        case BLE_GATTS_EVT_WRITE:
        	SEGGER_RTT_printf(0, "BLE GATTS Event: Write\n");
        	break;
        default:
        	SEGGER_RTT_printf(0, "BLE Event: Unknown, event id = 0x%02x\n", p_ble_evt->header.evt_id);
            break;
    }
}
#endif


#if defined (S120) || defined (S130)
/**@brief Function for handling the debug output messages.
 *
 * @param[in]   sys_evt   Event ID.
 */
void on_sys_evt_debug_messages(uint32_t sys_evt)
{

    SEGGER_RTT_printf(0, "[%6dms] SYS Event %d: ", TIMESTAMP*1000/32768, sys_evt);
	switch (sys_evt)
	{
	    case NRF_EVT_HFCLKSTARTED:
	    	SEGGER_RTT_printf(0, "NRF_EVT_HFCLKSTARTED\n");
	    	break;
	    case NRF_EVT_POWER_FAILURE_WARNING:
	    	SEGGER_RTT_printf(0, "NRF_EVT_POWER_FAILURE_WARNING\n");
	    	break;
	    case NRF_EVT_FLASH_OPERATION_SUCCESS:
	    	SEGGER_RTT_printf(0, "NRF_EVT_FLASH_OPERATION_SUCCESS\n");
	    	break;
	    case NRF_EVT_FLASH_OPERATION_ERROR:
	    	SEGGER_RTT_printf(0, "NRF_EVT_FLASH_OPERATION_ERROR\n");
	    	break;
	    case NRF_EVT_NUMBER_OF_EVTS:
	    	SEGGER_RTT_printf(0, "NRF_EVT_NUMBER_OF_EVTS\n");
	    	break;
	    default:
	    	SEGGER_RTT_printf(0, "Unknown ID\n");
	    	break;
	}
}
#endif


#if defined (S120) || defined (S130)
/**@brief Function for handling the debug output messages.
 *
 * @param[in]   p_ble_evt   Bluetooth stack event.
 */
void on_ble_evt_debug_messages(ble_evt_t * p_ble_evt)
{
    const ble_gap_evt_t* p_gap_evt = &p_ble_evt->evt.gap_evt;
    const ble_gattc_evt_t* p_gattc_evt = &p_ble_evt->evt.gattc_evt;

    SEGGER_RTT_printf(0, "[%6dms] ", TIMESTAMP*1000/32768);

    switch (p_ble_evt->header.evt_id)
    {
        case BLE_GAP_EVT_ADV_REPORT:
            SEGGER_RTT_printf(0, "BLE GAP Event: Advertising report: ");
            SEGGER_RTT_printf(0, "mac=%02x:%02x:%02x:%02x:%02x:%02x, ",     p_gap_evt->params.adv_report.peer_addr.addr[5], p_gap_evt->params.adv_report.peer_addr.addr[4], p_gap_evt->params.adv_report.peer_addr.addr[3], p_gap_evt->params.adv_report.peer_addr.addr[2], p_gap_evt->params.adv_report.peer_addr.addr[1], p_gap_evt->params.adv_report.peer_addr.addr[0]);
            SEGGER_RTT_printf(0, "mac type=%d, ",                           p_gap_evt->params.adv_report.peer_addr.addr_type);
            SEGGER_RTT_printf(0, "rssi=%ddB, ",                             p_gap_evt->params.adv_report.rssi);
            SEGGER_RTT_printf(0, "size=%d\n",                               p_gap_evt->params.adv_report.dlen);
            SEGGER_RTT_printf(0, "                          Advertising data: [ ");
            for (int i=0; i<p_gap_evt->params.adv_report.dlen; i++)
            	SEGGER_RTT_printf(0, "%02x ",                               p_gap_evt->params.adv_report.data[i]);
            SEGGER_RTT_printf(0, "]\n");
            break;
        case BLE_GAP_EVT_CONNECTED:
            SEGGER_RTT_printf(0, "BLE GAP Event: Connected to %02x:%02x:%02x:%02x:%02x:%02x\n",  p_gap_evt->params.adv_report.peer_addr.addr[5], p_gap_evt->params.adv_report.peer_addr.addr[4], p_gap_evt->params.adv_report.peer_addr.addr[3], p_gap_evt->params.adv_report.peer_addr.addr[2], p_gap_evt->params.adv_report.peer_addr.addr[1], p_gap_evt->params.adv_report.peer_addr.addr[0]);
            break;
        case BLE_GAP_EVT_DISCONNECTED:
            SEGGER_RTT_printf(0, "BLE GAP Event: Disconnected (reason = 0x%02x)\n",  p_gap_evt->params.disconnected.reason);
            break;
        case BLE_GAP_EVT_TIMEOUT:
        	switch (p_gap_evt->params.timeout.src)
        	{
        	    case BLE_GAP_TIMEOUT_SRC_SCAN:
        	        SEGGER_RTT_printf(0, "BLE GAP Event: Timeout (Scan)\n");
        	    	break;
        	    case BLE_GAP_TIMEOUT_SRC_CONN:
        	        SEGGER_RTT_printf(0, "BLE GAP Event: Timeout (Connection)\n");
        	    	break;
        	    default:
        	        SEGGER_RTT_printf(0, "BLE GAP Event: Timeout (Unknown source)\n");
        	    	break;
        	}
            break;
        case BLE_GAP_EVT_CONN_PARAM_UPDATE:
        	SEGGER_RTT_printf(0, "BLE GAP Event: Connection parameters have been updated:\n");
        	SEGGER_RTT_printf(0, "                                   [max. interval]           %d\n", p_gap_evt->params.conn_param_update.conn_params.max_conn_interval);
        	SEGGER_RTT_printf(0, "                                   [min. interval]           %d\n", p_gap_evt->params.conn_param_update.conn_params.min_conn_interval);
        	SEGGER_RTT_printf(0, "                                   [supervision timeout]     %d\n", p_gap_evt->params.conn_param_update.conn_params.conn_sup_timeout);
        	SEGGER_RTT_printf(0, "                                   [slave latency]           %d\n", p_gap_evt->params.conn_param_update.conn_params.slave_latency);
        	break;
        case BLE_GAP_EVT_CONN_PARAM_UPDATE_REQUEST:
            SEGGER_RTT_printf(0, "BLE GAP Event: Connection parameters update request\n");
            break;
        case BLE_GATTC_EVT_CHAR_VAL_BY_UUID_READ_RSP:
            SEGGER_RTT_printf(0, "BLE GATT Client Event: Read characteristic value by UUID response\n");
            SEGGER_RTT_printf(0, "                                   [count]                   %d (Handle-Value Pair Count)\n", p_gattc_evt->params.char_val_by_uuid_read_rsp.count);
            SEGGER_RTT_printf(0, "                                   [value_len]               %d (Length of the value in Handle-Value(s) list)\n", p_gattc_evt->params.char_val_by_uuid_read_rsp.value_len);
            SEGGER_RTT_printf(0, "                                   [handle_value[0].handle]  %d\n", p_gattc_evt->params.char_val_by_uuid_read_rsp.handle_value[0].handle);
            SEGGER_RTT_printf(0, "                                   [handle_value[0].p_value] 0x%08x\n", p_gattc_evt->params.char_val_by_uuid_read_rsp.handle_value[0].p_value);
            if (p_gattc_evt->params.char_val_by_uuid_read_rsp.count > 0)
            {
                int length = p_gattc_evt->params.char_val_by_uuid_read_rsp.value_len;
                int count = 0;
                SEGGER_RTT_printf(0, "                                   Data (hex):               ");
                do
                {
             	    SEGGER_RTT_printf(0, "%02x ", p_gattc_evt->params.char_val_by_uuid_read_rsp.handle_value[0].p_value[count++]);
                }
                while (count < length);
                SEGGER_RTT_printf(0, "\n");
        	}
            break;
        case BLE_GATTC_EVT_READ_RSP:
            SEGGER_RTT_printf(0, "BLE GATT Client Event: Read characteristic value response\n");
            SEGGER_RTT_printf(0, "                                   [handle]                  %d\n", p_gattc_evt->params.read_rsp.handle);
            SEGGER_RTT_printf(0, "                                   [offset]                  %d\n", p_gattc_evt->params.read_rsp.offset);
            SEGGER_RTT_printf(0, "                                   [length]                  %d\n", p_gattc_evt->params.read_rsp.len);
            if (p_gattc_evt->params.read_rsp.len > 0)
            {
                int length = p_gattc_evt->params.read_rsp.len;
                int count = 0;
                SEGGER_RTT_printf(0, "                                   Data (hex):               ");
                do
                {
                    SEGGER_RTT_printf(0, "%02x ", p_gattc_evt->params.read_rsp.data[count++]);
                }
                while (count < length);
                SEGGER_RTT_printf(0, "\n");
        	}
            break;
        case BLE_GATTC_EVT_WRITE_RSP:
            SEGGER_RTT_printf(0, "BLE GATT Client Event: Write characteristic value response\n");
            break;
        case BLE_GATTC_EVT_HVX:
            SEGGER_RTT_printf(0, "BLE GATT Client Event: Handle Value Notification or Indication\n");
            break;
        case BLE_GATTC_EVT_TIMEOUT:
            SEGGER_RTT_printf(0, "BLE GATT Client Event: Timeout\n");
            break;
        default:
            SEGGER_RTT_printf(0, "BLE Event: Unknown, event id = 0x%02x\n", p_ble_evt->header.evt_id);
            break;
    }
}
#endif

